==> owlapi-distribution-4.0.1-sources.jar: org/semanticweb/owlapi/io/StreamDocumentSource.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.io;

import java.io.InputStream;

import javax.annotation.Nonnull;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLDocumentFormat;

/**
 * An ontology document source which can read from a stream.
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.2.0
 */
public class StreamDocumentSource extends StreamDocumentSourceBase {

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param is
     *        The stream that the ontology representation will be read from.
     */
    public StreamDocumentSource(@Nonnull InputStream is) {
        this(is, getNextDocumentIRI("inputstream:ontology"), null, null);
    }

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param is
     *        The stream that the ontology representation will be read from.
     * @param iri
     *        The document IRI
     */
    public StreamDocumentSource(@Nonnull InputStream is, @Nonnull IRI iri) {
        this(is, iri, null, null);
    }

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param stream
     *        The stream that the ontology representation will be read from.
     * @param documentIRI
     *        The document IRI
     * @param f
     *        ontology format
     * @param mime
     *        mime type
     */
    public StreamDocumentSource(@Nonnull InputStream stream,
            @Nonnull IRI documentIRI, OWLDocumentFormat f, String mime) {
        super(stream, documentIRI, f, mime);
    }
}

==> owlapi-distribution-5.0.5-sources.jar: org/semanticweb/owlapi/io/StreamDocumentSource.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.io;

import java.io.InputStream;

import javax.annotation.Nullable;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLDocumentFormat;

/**
 * An ontology document source which can read from a stream.
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.2.0
 */
public class StreamDocumentSource extends StreamDocumentSourceBase {

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param is
     *        The stream that the ontology representation will be read from.
     */
    public StreamDocumentSource(InputStream is) {
        super(is, "inputstream:ontology", null, null);
    }

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param is
     *        The stream that the ontology representation will be read from.
     * @param iri
     *        The document IRI
     */
    public StreamDocumentSource(InputStream is, IRI iri) {
        super(is, iri, null, null);
    }

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param stream
     *        The stream that the ontology representation will be read from.
     * @param documentIRI
     *        The document IRI
     * @param f
     *        ontology format
     * @param mime
     *        mime type
     */
    public StreamDocumentSource(InputStream stream, IRI documentIRI, @Nullable OWLDocumentFormat f,
            @Nullable String mime) {
        super(stream, documentIRI, f, mime);
    }

    /**
     * Constructs an input source which will read an ontology from a
     * representation from the specified stream.
     * 
     * @param stream
     *        The stream that the ontology representation will be read from.
     * @param prefix
     *        The document IRI prefix
     * @param f
     *        ontology format
     * @param mime
     *        mime type
     */
    public StreamDocumentSource(InputStream stream, String prefix, @Nullable OWLDocumentFormat f,
            @Nullable String mime) {
        super(stream, prefix, f, mime);
    }
}
